@@ -38,11 +38,11 @@ from typing import (
     Tuple,
     TypeVar,
     Union,
+    cast,
     overload,
     runtime_checkable,
 )
 
-from . import utils
 from .context_managers import Typing
 from .enums import ChannelType
 from .errors import ClientException, InvalidArgument
@@ -54,6 +54,8 @@ from .mentions import AllowedMentions
 from .permissions import PermissionOverwrite, Permissions
 from .role import Role
 from .sticker import GuildSticker, StickerItem
+from .types.components import Component as ComponentPayload
+from .utils import MISSING, get, snowflake_time
 from .voice_client import VoiceClient, VoiceProtocol
 
 __all__ = (
@@ -73,7 +75,7 @@ if TYPE_CHECKING:
     from .asset import Asset
     from .channel import CategoryChannel, DMChannel, GroupChannel, PartialMessageable, TextChannel
     from .client import Client
-    from .embeds import Embed
+    from .embeds import Embed, EmbedData
     from .enums import InviteTarget
     from .guild import Guild
     from .member import Member
@@ -86,6 +88,10 @@ if TYPE_CHECKING:
         OverwriteType,
         PermissionOverwrite as PermissionOverwritePayload,
     )
+    from .types.message import (
+        AllowedMentions as AllowedMentionsPayload,
+        MessageReference as MessageReferencePayload,
+    )
     from .ui.view import View
     from .user import ClientUser
 
@@ -93,16 +99,6 @@ if TYPE_CHECKING:
     MessageableChannel = Union[PartialMessageableChannel, GroupChannel]
     SnowflakeTime = Union["Snowflake", datetime]
 
-MISSING = utils.MISSING
-
-
-class _Undefined:
-    def __repr__(self) -> str:
-        return "see-below"
-
-
-_undefined: Any = _Undefined()
-
 
 @runtime_checkable
 class Snowflake(Protocol):
@@ -115,7 +111,7 @@ class Snowflake(Protocol):
     :class:`.Object`.
 
     Attributes
-    -----------
+    ----------
     id: :class:`int`
         The model's unique ID.
     """
@@ -137,7 +133,7 @@ class User(Snowflake, Protocol):
     This ABC must also implement :class:`~nextcord.abc.Snowflake`.
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The user's username.
     discriminator: :class:`str`
@@ -178,7 +174,7 @@ class PrivateChannel(Snowflake, Protocol):
     This ABC must also implement :class:`~nextcord.abc.Snowflake`.
 
     Attributes
-    -----------
+    ----------
     me: :class:`~nextcord.ClientUser`
         The user presenting yourself.
     """
@@ -235,11 +231,12 @@ class GuildChannel:
     - :class:`~nextcord.VoiceChannel`
     - :class:`~nextcord.CategoryChannel`
     - :class:`~nextcord.StageChannel`
+    - :class:`~nextcord.ForumChannel`
 
     This ABC must also implement :class:`~nextcord.abc.Snowflake`.
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The channel name.
     guild: :class:`~nextcord.Guild`
@@ -311,7 +308,7 @@ class GuildChannel:
         payload = []
         for index, c in enumerate(channels):
             d: Dict[str, Any] = {"id": c.id, "position": index}
-            if parent_id is not _undefined and c.id == self.id:
+            if parent_id is not MISSING and c.id == self.id:
                 d.update(parent_id=parent_id, lock_permissions=lock_permissions)
             payload.append(d)
 
@@ -323,7 +320,7 @@ class GuildChannel:
         try:
             parent = options.pop("category")
         except KeyError:
-            parent_id = _undefined
+            parent_id = MISSING
         else:
             parent_id = parent and parent.id
 
@@ -346,12 +343,19 @@ class GuildChannel:
         else:
             options["video_quality_mode"] = int(video_quality_mode)
 
+        try:
+            default_sort_order = options.pop("default_sort_order")
+        except KeyError:
+            pass
+        else:
+            options["default_sort_order"] = default_sort_order.value
+
         lock_permissions = options.pop("sync_permissions", False)
 
         try:
             position = options.pop("position")
         except KeyError:
-            if parent_id is not _undefined:
+            if parent_id is not MISSING:
                 if lock_permissions:
                     category = self.guild.get_channel(parent_id)
                     if category:
@@ -455,19 +459,19 @@ class GuildChannel:
     @property
     def created_at(self) -> datetime:
         """:class:`datetime.datetime`: Returns the channel's creation time in UTC."""
-        return utils.snowflake_time(self.id)
+        return snowflake_time(self.id)
 
     def overwrites_for(self, obj: Union[Role, User]) -> PermissionOverwrite:
         """Returns the channel-specific overwrites for a member or a role.
 
         Parameters
-        -----------
+        ----------
         obj: Union[:class:`~nextcord.Role`, :class:`~nextcord.abc.User`]
             The role or user denoting
             whose overwrite to get.
 
         Returns
-        ---------
+        -------
         :class:`~nextcord.PermissionOverwrite`
             The permission overwrites for this object.
         """
@@ -497,7 +501,7 @@ class GuildChannel:
         overwrite as a :class:`~nextcord.PermissionOverwrite`.
 
         Returns
-        --------
+        -------
         Dict[Union[:class:`~nextcord.Role`, :class:`~nextcord.Member`], :class:`~nextcord.PermissionOverwrite`]
             The channel's permission overwrites.
         """
@@ -563,6 +567,7 @@ class GuildChannel:
         - Guild roles
         - Channel overrides
         - Member overrides
+        - Timed-out members
 
         If a :class:`~nextcord.Role` is passed, then it checks the permissions
         someone with that role would have, which is essentially:
@@ -572,6 +577,9 @@ class GuildChannel:
         - The default role permission overwrites
         - The permission overwrites of the role used as a parameter
 
+        .. versionchanged:: 2.3
+            Only ``view_channel`` and ``read_message_history`` can be returned for timed-out members
+
         .. versionchanged:: 2.0
             The object passed in can now be a role object.
 
@@ -626,7 +634,7 @@ class GuildChannel:
             if obj.is_default():
                 return base
 
-            overwrite = utils.get(self._overwrites, type=_Overwrites.ROLE, id=obj.id)
+            overwrite = get(self._overwrites, type=_Overwrites.ROLE, id=obj.id)
             if overwrite is not None:
                 base.handle_overwrite(overwrite.allow, overwrite.deny)
 
@@ -687,6 +695,11 @@ class GuildChannel:
             denied = Permissions.all_channel()
             base.value &= ~denied.value
 
+        # if you are timed out then you lose all permissions except view_channel and read_message_history
+        if obj.communication_disabled_until is not None:
+            allowed = Permissions(view_channel=True, read_message_history=True)
+            base.value &= allowed.value
+
         return base
 
     async def delete(self, *, reason: Optional[str] = None) -> None:
@@ -697,13 +710,13 @@ class GuildChannel:
         You must have :attr:`~nextcord.Permissions.manage_channels` permission to use this.
 
         Parameters
-        -----------
+        ----------
         reason: Optional[:class:`str`]
             The reason for deleting this channel.
             Shows up on the audit log.
 
         Raises
-        -------
+        ------
         ~nextcord.Forbidden
             You do not have proper permissions to delete the channel.
         ~nextcord.NotFound
@@ -718,7 +731,7 @@ class GuildChannel:
         self,
         target: Union[Member, Role],
         *,
-        overwrite: Optional[Union[PermissionOverwrite, _Undefined]] = ...,
+        overwrite: Optional[PermissionOverwrite] = ...,
         reason: Optional[str] = ...,
     ) -> None:
         ...
@@ -733,7 +746,7 @@ class GuildChannel:
     ) -> None:
         ...
 
-    async def set_permissions(self, target, *, overwrite=_undefined, reason=None, **permissions):
+    async def set_permissions(self, target, *, overwrite=MISSING, reason=None, **permissions):
         r"""|coro|
 
         Sets the channel specific permission overwrites for a target in the
@@ -758,7 +771,7 @@ class GuildChannel:
             This method *replaces* the old overwrites with the ones given.
 
         Examples
-        ----------
+        --------
 
         Setting allow and deny: ::
 
@@ -777,7 +790,7 @@ class GuildChannel:
             await channel.set_permissions(member, overwrite=overwrite)
 
         Parameters
-        -----------
+        ----------
         target: Union[:class:`~nextcord.Member`, :class:`~nextcord.Role`]
             The member or role to overwrite permissions for.
         overwrite: Optional[:class:`~nextcord.PermissionOverwrite`]
@@ -790,7 +803,7 @@ class GuildChannel:
             The reason for doing this action. Shows up on the audit log.
 
         Raises
-        -------
+        ------
         ~nextcord.Forbidden
             You do not have permissions to edit channel specific permissions.
         ~nextcord.HTTPException
@@ -811,7 +824,7 @@ class GuildChannel:
         else:
             raise InvalidArgument("target parameter must be either Member or Role")
 
-        if overwrite is _undefined:
+        if overwrite is MISSING:
             if len(permissions) == 0:
                 raise InvalidArgument("No overwrite provided.")
             try:
@@ -867,7 +880,7 @@ class GuildChannel:
         .. versionadded:: 1.1
 
         Parameters
-        ------------
+        ----------
         name: Optional[:class:`str`]
             The name of the new channel. If not provided, defaults to this
             channel name.
@@ -875,14 +888,14 @@ class GuildChannel:
             The reason for cloning this channel. Shows up on the audit log.
 
         Raises
-        -------
+        ------
         ~nextcord.Forbidden
             You do not have the proper permissions to create this channel.
         ~nextcord.HTTPException
             Creating the channel failed.
 
         Returns
-        --------
+        -------
         :class:`.abc.GuildChannel`
             The channel that was created.
         """
@@ -954,7 +967,7 @@ class GuildChannel:
         .. versionadded:: 1.7
 
         Parameters
-        ------------
+        ----------
         beginning: :class:`bool`
             Whether to move the channel to the beginning of the
             channel list (or category if given).
@@ -986,7 +999,7 @@ class GuildChannel:
             The reason for the move.
 
         Raises
-        -------
+        ------
         InvalidArgument
             An invalid position was given or a bad mix of arguments were passed.
         Forbidden
@@ -1079,7 +1092,7 @@ class GuildChannel:
         do this.
 
         Parameters
-        ------------
+        ----------
         max_age: :class:`int`
             How long the invite should last in seconds. If it's 0 then the invite
             doesn't expire. Defaults to ``0``.
@@ -1101,17 +1114,19 @@ class GuildChannel:
             .. versionadded:: 2.0
 
         target_user: Optional[:class:`User`]
-            The user whose stream to display for this invite, required if `target_type` is `TargetType.stream`. The user must be streaming in the channel.
+            The user whose stream to display for this invite, required if ``target_type``
+            is :attr:`.InviteTarget.stream`. The user must be streaming in the channel.
 
             .. versionadded:: 2.0
 
         target_application_id:: Optional[:class:`int`]
-            The id of the embedded application for the invite, required if `target_type` is `TargetType.embedded_application`.
+            The id of the embedded application for the invite, required if ``target_type``
+            is :attr:`.InviteTarget.embedded_application`.
 
             .. versionadded:: 2.0
 
         Raises
-        -------
+        ------
         ~nextcord.HTTPException
             Invite creation failed.
 
@@ -1119,7 +1134,7 @@ class GuildChannel:
             The channel that was passed is a category or an invalid channel.
 
         Returns
-        --------
+        -------
         :class:`~nextcord.Invite`
             The invite that was created.
         """
@@ -1145,7 +1160,7 @@ class GuildChannel:
         You must have :attr:`~nextcord.Permissions.manage_channels` to get this information.
 
         Raises
-        -------
+        ------
         ~nextcord.Forbidden
             You do not have proper permissions to get the information.
         ~nextcord.HTTPException
@@ -1192,13 +1207,13 @@ class Messageable:
         tts: bool = ...,
         embed: Embed = ...,
         file: File = ...,
-        stickers: Sequence[Union[GuildSticker, StickerItem]] = ...,
-        delete_after: float = ...,
-        nonce: Union[str, int] = ...,
-        allowed_mentions: AllowedMentions = ...,
-        reference: Union[Message, MessageReference, PartialMessage] = ...,
-        mention_author: bool = ...,
-        view: View = ...,
+        stickers: Optional[Sequence[Union[GuildSticker, StickerItem]]] = ...,
+        delete_after: Optional[float] = ...,
+        nonce: Optional[Union[str, int]] = ...,
+        allowed_mentions: Optional[AllowedMentions] = ...,
+        reference: Optional[Union[Message, MessageReference, PartialMessage]] = ...,
+        mention_author: Optional[bool] = ...,
+        view: Optional[View] = ...,
     ) -> Message:
         ...
 
@@ -1210,13 +1225,13 @@ class Messageable:
         tts: bool = ...,
         embed: Embed = ...,
         files: List[File] = ...,
-        stickers: Sequence[Union[GuildSticker, StickerItem]] = ...,
-        delete_after: float = ...,
-        nonce: Union[str, int] = ...,
-        allowed_mentions: AllowedMentions = ...,
-        reference: Union[Message, MessageReference, PartialMessage] = ...,
-        mention_author: bool = ...,
-        view: View = ...,
+        stickers: Optional[Sequence[Union[GuildSticker, StickerItem]]] = ...,
+        delete_after: Optional[float] = ...,
+        nonce: Optional[Union[str, int]] = ...,
+        allowed_mentions: Optional[AllowedMentions] = ...,
+        reference: Optional[Union[Message, MessageReference, PartialMessage]] = ...,
+        mention_author: Optional[bool] = ...,
+        view: Optional[View] = ...,
     ) -> Message:
         ...
 
@@ -1228,13 +1243,13 @@ class Messageable:
         tts: bool = ...,
         embeds: List[Embed] = ...,
         file: File = ...,
-        stickers: Sequence[Union[GuildSticker, StickerItem]] = ...,
-        delete_after: float = ...,
-        nonce: Union[str, int] = ...,
-        allowed_mentions: AllowedMentions = ...,
-        reference: Union[Message, MessageReference, PartialMessage] = ...,
-        mention_author: bool = ...,
-        view: View = ...,
+        stickers: Optional[Sequence[Union[GuildSticker, StickerItem]]] = ...,
+        delete_after: Optional[float] = ...,
+        nonce: Optional[Union[str, int]] = ...,
+        allowed_mentions: Optional[AllowedMentions] = ...,
+        reference: Optional[Union[Message, MessageReference, PartialMessage]] = ...,
+        mention_author: Optional[bool] = ...,
+        view: Optional[View] = ...,
     ) -> Message:
         ...
 
@@ -1246,32 +1261,32 @@ class Messageable:
         tts: bool = ...,
         embeds: List[Embed] = ...,
         files: List[File] = ...,
-        stickers: Sequence[Union[GuildSticker, StickerItem]] = ...,
-        delete_after: float = ...,
-        nonce: Union[str, int] = ...,
-        allowed_mentions: AllowedMentions = ...,
-        reference: Union[Message, MessageReference, PartialMessage] = ...,
-        mention_author: bool = ...,
-        view: View = ...,
+        stickers: Optional[Sequence[Union[GuildSticker, StickerItem]]] = ...,
+        delete_after: Optional[float] = ...,
+        nonce: Optional[Union[str, int]] = ...,
+        allowed_mentions: Optional[AllowedMentions] = ...,
+        reference: Optional[Union[Message, MessageReference, PartialMessage]] = ...,
+        mention_author: Optional[bool] = ...,
+        view: Optional[View] = ...,
     ) -> Message:
         ...
 
     async def send(
         self,
-        content=None,
+        content: Optional[str] = None,
         *,
-        tts=None,
-        embed=None,
-        embeds=None,
-        file=None,
-        files=None,
-        stickers=None,
-        delete_after=None,
-        nonce=None,
-        allowed_mentions=None,
-        reference=None,
-        mention_author=None,
-        view=None,
+        tts: bool = False,
+        embed: Optional[Embed] = None,
+        embeds: Optional[List[Embed]] = None,
+        file: Optional[File] = None,
+        files: Optional[List[File]] = None,
+        stickers: Optional[Sequence[Union[GuildSticker, StickerItem]]] = None,
+        delete_after: Optional[float] = None,
+        nonce: Optional[Union[str, int]] = None,
+        allowed_mentions: Optional[AllowedMentions] = None,
+        reference: Optional[Union[Message, MessageReference, PartialMessage]] = None,
+        mention_author: Optional[bool] = None,
+        view: Optional[View] = None,
     ):
         """|coro|
 
@@ -1292,7 +1307,7 @@ class Messageable:
         **Specifying both parameters will lead to an exception**.
 
         Parameters
-        ------------
+        ----------
         content: Optional[:class:`str`]
             The content of the message to send.
         tts: :class:`bool`
@@ -1303,7 +1318,7 @@ class Messageable:
             The file to upload.
         files: List[:class:`~nextcord.File`]
             A list of files to upload. Must be a maximum of 10.
-        nonce: :class:`int`
+        nonce: Union[:class:`int`, :class:`str`]
             The nonce to use for sending this message. If the message was successfully sent,
             then the message will have a nonce with this value.
         delete_after: :class:`float`
@@ -1344,7 +1359,7 @@ class Messageable:
             .. versionadded:: 2.0
 
         Raises
-        --------
+        ------
         ~nextcord.HTTPException
             Sending the message failed.
         ~nextcord.Forbidden
@@ -1357,7 +1372,7 @@ class Messageable:
             :class:`~nextcord.MessageReference` or :class:`~nextcord.PartialMessage`.
 
         Returns
-        ---------
+        -------
         :class:`~nextcord.Message`
             The message that was sent.
         """
@@ -1366,45 +1381,50 @@ class Messageable:
         state = self._state
         content = str(content) if content is not None else None
 
+        embed_payload: Optional[EmbedData] = None
+        embeds_payload: Optional[List[EmbedData]] = None
+        stickers_payload: Optional[List[int]] = None
+        reference_payload: Optional[MessageReferencePayload] = None
+        allowed_mentions_payload: Optional[AllowedMentionsPayload] = None
+
         if embed is not None and embeds is not None:
             raise InvalidArgument("Cannot pass both embed and embeds parameter to send()")
 
         if embed is not None:
-            embed = embed.to_dict()
+            embed_payload = embed.to_dict()
 
         elif embeds is not None:
-            embeds = [embed.to_dict() for embed in embeds]
+            embeds_payload = [em.to_dict() for em in embeds]
 
         if stickers is not None:
-            stickers = [sticker.id for sticker in stickers]
+            stickers_payload = [sticker.id for sticker in stickers]
 
         if allowed_mentions is not None:
             if state.allowed_mentions is not None:
-                allowed_mentions = state.allowed_mentions.merge(allowed_mentions).to_dict()
+                allowed_mentions_payload = state.allowed_mentions.merge(allowed_mentions).to_dict()
             else:
-                allowed_mentions = allowed_mentions.to_dict()
+                allowed_mentions_payload = allowed_mentions.to_dict()
         else:
-            allowed_mentions = state.allowed_mentions and state.allowed_mentions.to_dict()
+            allowed_mentions_payload = state.allowed_mentions and state.allowed_mentions.to_dict()
 
         if mention_author is not None:
-            allowed_mentions = allowed_mentions or AllowedMentions().to_dict()
-            allowed_mentions["replied_user"] = bool(mention_author)
+            allowed_mentions_payload = allowed_mentions_payload or AllowedMentions().to_dict()
+            allowed_mentions_payload["replied_user"] = bool(mention_author)
 
         if reference is not None:
             try:
-                reference = reference.to_message_reference_dict()
+                reference_payload = reference.to_message_reference_dict()
             except AttributeError:
                 raise InvalidArgument(
                     "reference parameter must be Message, MessageReference, or PartialMessage"
                 ) from None
 
+        components: Optional[List[ComponentPayload]] = None
         if view:
             if not hasattr(view, "__discord_ui_view__"):
                 raise InvalidArgument(f"view parameter must be View not {view.__class__!r}")
 
-            components = view.to_components()
-        else:
-            components = None
+            components = cast(List[ComponentPayload], view.to_components())
 
         if file is not None and files is not None:
             raise InvalidArgument("Cannot pass both file and files parameter to send()")
@@ -1417,14 +1437,14 @@ class Messageable:
                 data = await state.http.send_files(
                     channel.id,
                     files=[file],
-                    allowed_mentions=allowed_mentions,
+                    allowed_mentions=allowed_mentions_payload,
                     content=content,
                     tts=tts,
-                    embed=embed,
-                    embeds=embeds,
+                    embed=embed_payload,
+                    embeds=embeds_payload,
                     nonce=nonce,
-                    message_reference=reference,
-                    stickers=stickers,
+                    message_reference=reference_payload,
+                    stickers=stickers_payload,
                     components=components,
                 )
             finally:
@@ -1440,12 +1460,12 @@ class Messageable:
                     files=files,
                     content=content,
                     tts=tts,
-                    embed=embed,
-                    embeds=embeds,
+                    embed=embed_payload,
+                    embeds=embeds_payload,
                     nonce=nonce,
-                    allowed_mentions=allowed_mentions,
-                    message_reference=reference,
-                    stickers=stickers,
+                    allowed_mentions=allowed_mentions_payload,
+                    message_reference=reference_payload,
+                    stickers=stickers_payload,
                     components=components,
                 )
             finally:
@@ -1456,12 +1476,12 @@ class Messageable:
                 channel.id,
                 content,
                 tts=tts,
-                embed=embed,
-                embeds=embeds,
+                embed=embed_payload,
+                embeds=embeds_payload,
                 nonce=nonce,
-                allowed_mentions=allowed_mentions,
-                message_reference=reference,
-                stickers=stickers,
+                allowed_mentions=allowed_mentions_payload,
+                message_reference=reference_payload,
+                stickers=stickers_payload,
                 components=components,
             )
 
@@ -1511,12 +1531,12 @@ class Messageable:
         Retrieves a single :class:`~nextcord.Message` from the destination.
 
         Parameters
-        ------------
+        ----------
         id: :class:`int`
             The message ID to look for.
 
         Raises
-        --------
+        ------
         ~nextcord.NotFound
             The specified message was not found.
         ~nextcord.Forbidden
@@ -1525,7 +1545,7 @@ class Messageable:
             Retrieving the message failed.
 
         Returns
-        --------
+        -------
         :class:`~nextcord.Message`
             The message asked for.
         """
@@ -1548,7 +1568,7 @@ class Messageable:
         You must have :attr:`~nextcord.Permissions.read_message_history` permissions to use this.
 
         Examples
-        ---------
+        --------
 
         Usage ::
 
@@ -1565,7 +1585,7 @@ class Messageable:
         All parameters are optional.
 
         Parameters
-        -----------
+        ----------
         limit: Optional[:class:`int`]
             The number of messages to retrieve.
             If ``None``, retrieves every message in the channel. Note, however,
@@ -1596,7 +1616,7 @@ class Messageable:
             The request to get message history failed.
 
         Yields
-        -------
+        ------
         :class:`~nextcord.Message`
             The message with the message data parsed.
         """
@@ -1644,7 +1664,7 @@ class Connectable(Protocol):
         This requires :attr:`Intents.voice_states`.
 
         Parameters
-        -----------
+        ----------
         timeout: :class:`float`
             The timeout in seconds to wait for the voice endpoint.
         reconnect: :class:`bool`
@@ -1656,7 +1676,7 @@ class Connectable(Protocol):
             Defaults to :class:`~nextcord.VoiceClient`.
 
         Raises
-        -------
+        ------
         asyncio.TimeoutError
             Could not connect to the voice channel in time.
         ~nextcord.ClientException
@@ -1665,7 +1685,7 @@ class Connectable(Protocol):
             The opus library has not been loaded.
 
         Returns
-        --------
+        -------
         :class:`~nextcord.VoiceProtocol`
             A voice client that is fully connected to the voice server.
         """
