@@ -47,7 +47,14 @@ from typing import (
 
 from . import abc, ui, utils
 from .asset import Asset
-from .enums import ChannelType, StagePrivacyLevel, VideoQualityMode, VoiceRegion, try_enum
+from .enums import (
+    ChannelType,
+    SortOrderType,
+    StagePrivacyLevel,
+    VideoQualityMode,
+    VoiceRegion,
+    try_enum,
+)
 from .errors import ClientException, InvalidArgument
 from .file import File
 from .flags import ChannelFlags
@@ -122,7 +129,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             Returns the channel's name.
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The channel name.
     guild: :class:`Guild`
@@ -141,7 +148,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
         *not* point to an existing or valid message.
     slowmode_delay: :class:`int`
         The number of seconds a member must wait between sending messages
-        in this channel. A value of `0` denotes that it is disabled.
+        in this channel. A value of ``0`` denotes that it is disabled.
         Bots and users with :attr:`~Permissions.manage_channels` or
         :attr:`~Permissions.manage_messages` bypass slowmode.
     flags: :class:`ChannelFlags`
@@ -198,7 +205,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
     def _update(self, guild: Guild, data: TextChannelPayload) -> None:
         self.guild: Guild = guild
         self.name: str = data["name"]
-        self.category_id: Optional[int] = utils._get_as_snowflake(data, "parent_id")
+        self.category_id: Optional[int] = utils.get_as_snowflake(data, "parent_id")
         self.topic: Optional[str] = data.get("topic")
         self.position: int = data["position"]
         self.nsfw: bool = data.get("nsfw", False)
@@ -209,7 +216,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
         )
         self.flags: ChannelFlags = ChannelFlags._from_value(data.get("flags", 0))
         self._type: int = data.get("type", self._type)
-        self.last_message_id: Optional[int] = utils._get_as_snowflake(data, "last_message_id")
+        self.last_message_id: Optional[int] = utils.get_as_snowflake(data, "last_message_id")
         self._fill_overwrites(data)
 
     async def _get_channel(self):
@@ -269,7 +276,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             attribute.
 
         Returns
-        ---------
+        -------
         Optional[:class:`Message`]
             The last message in this channel or ``None`` if not found.
         """
@@ -333,7 +340,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             category.
         slowmode_delay: :class:`int`
             Specifies the slowmode rate limit for user in this channel, in seconds.
-            A value of `0` disables slowmode. The maximum value possible is `21600`.
+            A value of ``0`` disables slowmode. The maximum value possible is ``21600``.
         type: :class:`ChannelType`
             Change the type of this text channel. Currently, only conversion between
             :attr:`ChannelType.text` and :attr:`ChannelType.news` is supported. This
@@ -358,7 +365,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             Editing the channel failed.
 
         Returns
-        --------
+        -------
         Optional[:class:`.TextChannel`]
             The newly edited text channel. If the edit was only positional
             then ``None`` is returned instead.
@@ -396,7 +403,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
         use this.
 
         Parameters
-        -----------
+        ----------
         messages: Iterable[:class:`abc.Snowflake`]
             An iterable of messages denoting which ones to bulk delete.
 
@@ -451,7 +458,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
         also needed to retrieve message history.
 
         Examples
-        ---------
+        --------
 
         Deleting bot's messages ::
 
@@ -462,7 +469,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             await channel.send(f'Deleted {len(deleted)} message(s)')
 
         Parameters
-        -----------
+        ----------
         limit: Optional[:class:`int`]
             The number of messages to search through. This is not the number
             of messages that will be deleted, though it can be.
@@ -483,14 +490,14 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             fall back to single delete if messages are older than two weeks.
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have proper permissions to do the actions required.
         HTTPException
             Purging the messages failed.
 
         Returns
-        --------
+        -------
         List[:class:`.Message`]
             The list of messages that were deleted.
         """
@@ -550,12 +557,12 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
         Requires :attr:`~.Permissions.manage_webhooks` permissions.
 
         Raises
-        -------
+        ------
         Forbidden
             You don't have permissions to get the webhooks.
 
         Returns
-        --------
+        -------
         List[:class:`Webhook`]
             The webhooks for this channel.
         """
@@ -585,7 +592,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             The ``avatar`` parameter now accepts :class:`File`, :class:`Attachment`, and :class:`Asset`.
 
         Parameters
-        -------------
+        ----------
         name: :class:`str`
             The webhook's name.
         avatar: Optional[Union[:class:`bytes`, :class:`Asset`, :class:`Attachment`, :class:`File`]]
@@ -596,21 +603,21 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             The reason for creating this webhook. Shows up in the audit logs.
 
         Raises
-        -------
+        ------
         HTTPException
             Creating the webhook failed.
         Forbidden
             You do not have permissions to create a webhook.
 
         Returns
-        --------
+        -------
         :class:`Webhook`
             The created webhook.
         """
 
         from .webhook import Webhook
 
-        avatar_base64 = await utils._obj_to_base64_data(avatar)
+        avatar_base64 = await utils.obj_to_base64_data(avatar)
 
         data = await self._state.http.create_webhook(
             self.id, name=str(name), avatar=avatar_base64, reason=reason
@@ -631,7 +638,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
         .. versionadded:: 1.3
 
         Parameters
-        -----------
+        ----------
         destination: :class:`TextChannel`
             The channel you would like to follow from.
         reason: Optional[:class:`str`]
@@ -640,14 +647,14 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             .. versionadded:: 1.4
 
         Raises
-        -------
+        ------
         HTTPException
             Following the channel failed.
         Forbidden
             You do not have the permissions to create a webhook.
 
         Returns
-        --------
+        -------
         :class:`Webhook`
             The created webhook.
         """
@@ -674,12 +681,12 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
         .. versionadded:: 1.6
 
         Parameters
-        ------------
+        ----------
         message_id: :class:`int`
             The message ID to create a partial message for.
 
         Returns
-        ---------
+        -------
         :class:`PartialMessage`
             The partial message.
         """
@@ -694,12 +701,12 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
         .. versionadded:: 2.0
 
         Parameters
-        -----------
+        ----------
         thread_id: :class:`int`
             The ID to search for.
 
         Returns
-        --------
+        -------
         Optional[:class:`Thread`]
             The returned thread or ``None`` if not found.
         """
@@ -724,7 +731,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
         .. versionadded:: 2.0
 
         Parameters
-        -----------
+        ----------
         name: :class:`str`
             The name of the thread.
         message: Optional[:class:`abc.Snowflake`]
@@ -742,14 +749,14 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable, PinsMixin):
             The reason for creating a new thread. Shows up on the audit log.
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have permissions to create a thread.
         HTTPException
             Starting the thread failed.
 
         Returns
-        --------
+        -------
         :class:`Thread`
             The created thread
         """
@@ -876,6 +883,10 @@ class ForumChannel(abc.GuildChannel, Hashable):
         The archive duration which threads from this channel inherit by default.
     last_message_id: :class:`int`
         The snowflake ID of the message starting the last thread in this channel.
+    default_sort_order: :class:`SortOrderType`
+        The default sort order type used to sort posts in forum channels.
+
+        .. versionadded:: 2.3
     """
 
     __slots__ = (
@@ -890,6 +901,7 @@ class ForumChannel(abc.GuildChannel, Hashable):
         "slowmode_delay",
         "default_auto_archive_duration",
         "last_message_id",
+        "default_sort_order",
         "_state",
         "_type",
         "_overwrites",
@@ -904,7 +916,7 @@ class ForumChannel(abc.GuildChannel, Hashable):
     def _update(self, guild: Guild, data: ForumChannelPayload) -> None:
         self.guild = guild
         self.name = data["name"]
-        self.category_id: Optional[int] = utils._get_as_snowflake(data, "parent_id")
+        self.category_id: Optional[int] = utils.get_as_snowflake(data, "parent_id")
         self.topic: Optional[str] = data.get("topic")
         self.position: int = data["position"]
         self.nsfw: bool = data.get("nsfw", False)
@@ -914,7 +926,12 @@ class ForumChannel(abc.GuildChannel, Hashable):
         self.default_auto_archive_duration: ThreadArchiveDuration = data.get(
             "default_auto_archive_duration", 1440
         )
-        self.last_message_id: Optional[int] = utils._get_as_snowflake(data, "last_message_id")
+
+        self.last_message_id: Optional[int] = utils.get_as_snowflake(data, "last_message_id")
+        if sort_order := data.get("default_sort_order"):
+            self.default_sort_order: Optional[SortOrderType] = try_enum(SortOrderType, sort_order)
+        else:
+            self.default_sort_order: Optional[SortOrderType] = None
         self._fill_overwrites(data)
 
     async def _get_channel(self):
@@ -988,6 +1005,7 @@ class ForumChannel(abc.GuildChannel, Hashable):
         overwrites: Mapping[Union[Role, Member, Snowflake], PermissionOverwrite] = ...,
         flags: ChannelFlags = ...,
         reason: Optional[str] = ...,
+        default_sort_order: Optional[SortOrderType] = ...,
     ) -> ForumChannel:
         ...
 
@@ -1021,7 +1039,7 @@ class ForumChannel(abc.GuildChannel, Hashable):
             category.
         slowmode_delay: :class:`int`
             Specifies the slowmode rate limit for user in this channel, in seconds.
-            A value of `0` disables slowmode. The maximum value possible is `21600`.
+            A value of ``0`` disables slowmode. The maximum value possible is ``21600``.
         reason: Optional[:class:`str`]
             The reason for editing this channel. Shows up on the audit log.
         overwrites: :class:`Mapping`
@@ -1030,6 +1048,10 @@ class ForumChannel(abc.GuildChannel, Hashable):
         default_auto_archive_duration: :class:`int`
             The new default auto archive duration in minutes for threads created in this channel.
             Must be one of ``60``, ``1440``, ``4320``, or ``10080``.
+        default_sort_order: :class:`SortOrderType`
+            The default sort order type used to sort posts in forum channels.
+
+            .. versionadded:: 2.3
 
         Raises
         ------
@@ -1319,7 +1341,7 @@ class VocalGuildChannel(abc.Connectable, abc.GuildChannel, Hashable):
         self.video_quality_mode: VideoQualityMode = try_enum(
             VideoQualityMode, data.get("video_quality_mode", 1)
         )
-        self.category_id: Optional[int] = utils._get_as_snowflake(data, "parent_id")
+        self.category_id: Optional[int] = utils.get_as_snowflake(data, "parent_id")
         self.position: int = data["position"]
         self.bitrate: int = data.get("bitrate")
         self.user_limit: int = data.get("user_limit")
@@ -1353,7 +1375,7 @@ class VocalGuildChannel(abc.Connectable, abc.GuildChannel, Hashable):
             when the member cache is unavailable.
 
         Returns
-        --------
+        -------
         Mapping[:class:`int`, :class:`VoiceState`]
             The mapping of member ID to a voice state.
         """
@@ -1400,7 +1422,7 @@ class VoiceChannel(VocalGuildChannel, abc.Messageable):
             Returns the channel's name.
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The channel name.
     guild: :class:`Guild`
@@ -1465,7 +1487,7 @@ class VoiceChannel(VocalGuildChannel, abc.Messageable):
 
     def _update(self, guild: Guild, data: VoiceChannelPayload) -> None:
         VocalGuildChannel._update(self, guild, data)
-        self.last_message_id: Optional[int] = utils._get_as_snowflake(data, "last_message_id")
+        self.last_message_id: Optional[int] = utils.get_as_snowflake(data, "last_message_id")
         self.nsfw: bool = data.get("nsfw", False)
 
     async def _get_channel(self):
@@ -1497,7 +1519,7 @@ class VoiceChannel(VocalGuildChannel, abc.Messageable):
         .. versionadded:: 2.1
 
         Returns
-        ---------
+        -------
         Optional[:class:`Message`]
             The last message in this channel or ``None`` if not found.
         """
@@ -1588,7 +1610,7 @@ class VoiceChannel(VocalGuildChannel, abc.Messageable):
             Editing the channel failed.
 
         Returns
-        --------
+        -------
         Optional[:class:`.VoiceChannel`]
             The newly edited voice channel. If the edit was only positional
             then ``None`` is returned instead.
@@ -1618,7 +1640,7 @@ class VoiceChannel(VocalGuildChannel, abc.Messageable):
         .. versionadded:: 2.1
 
         Parameters
-        -----------
+        ----------
         messages: Iterable[:class:`abc.Snowflake`]
             An iterable of messages denoting which ones to bulk delete.
 
@@ -1675,7 +1697,7 @@ class VoiceChannel(VocalGuildChannel, abc.Messageable):
         .. versionadded:: 2.1
 
         Examples
-        ---------
+        --------
 
         Deleting bot's messages ::
 
@@ -1686,7 +1708,7 @@ class VoiceChannel(VocalGuildChannel, abc.Messageable):
             await channel.send(f'Deleted {len(deleted)} message(s)')
 
         Parameters
-        -----------
+        ----------
         limit: Optional[:class:`int`]
             The number of messages to search through. This is not the number
             of messages that will be deleted, though it can be.
@@ -1707,14 +1729,14 @@ class VoiceChannel(VocalGuildChannel, abc.Messageable):
             fall back to single delete if messages are older than two weeks.
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have proper permissions to do the actions required.
         HTTPException
             Purging the messages failed.
 
         Returns
-        --------
+        -------
         List[:class:`.Message`]
             The list of messages that were deleted.
         """
@@ -1791,7 +1813,7 @@ class StageChannel(VocalGuildChannel):
             Returns the channel's name.
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The channel name.
     guild: :class:`Guild`
@@ -1923,7 +1945,7 @@ class StageChannel(VocalGuildChannel):
         .. versionadded:: 2.0
 
         Parameters
-        -----------
+        ----------
         topic: :class:`str`
             The stage instance's topic.
         privacy_level: :class:`StagePrivacyLevel`
@@ -1941,7 +1963,7 @@ class StageChannel(VocalGuildChannel):
             Creating a stage instance failed.
 
         Returns
-        --------
+        -------
         :class:`StageInstance`
             The newly created stage instance.
         """
@@ -1965,14 +1987,14 @@ class StageChannel(VocalGuildChannel):
         .. versionadded:: 2.0
 
         Raises
-        -------
+        ------
         :exc:`.NotFound`
             The stage instance or channel could not be found.
         :exc:`.HTTPException`
             Getting the stage instance failed.
 
         Returns
-        --------
+        -------
         :class:`StageInstance`
             The stage instance.
         """
@@ -2049,7 +2071,7 @@ class StageChannel(VocalGuildChannel):
             Editing the channel failed.
 
         Returns
-        --------
+        -------
         Optional[:class:`.StageChannel`]
             The newly edited stage channel. If the edit was only positional
             then ``None`` is returned instead.
@@ -2085,7 +2107,7 @@ class CategoryChannel(abc.GuildChannel, Hashable):
             Returns the category's name.
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The category name.
     guild: :class:`Guild`
@@ -2130,7 +2152,7 @@ class CategoryChannel(abc.GuildChannel, Hashable):
     def _update(self, guild: Guild, data: CategoryChannelPayload) -> None:
         self.guild: Guild = guild
         self.name: str = data["name"]
-        self.category_id: Optional[int] = utils._get_as_snowflake(data, "parent_id")
+        self.category_id: Optional[int] = utils.get_as_snowflake(data, "parent_id")
         self.nsfw: bool = data.get("nsfw", False)
         self.position: int = data["position"]
         self.flags: ChannelFlags = ChannelFlags._from_value(data.get("flags", 0))
@@ -2210,7 +2232,7 @@ class CategoryChannel(abc.GuildChannel, Hashable):
             Editing the category failed.
 
         Returns
-        --------
+        -------
         Optional[:class:`.CategoryChannel`]
             The newly edited category channel. If the edit was only positional
             then ``None`` is returned instead.
@@ -2418,13 +2440,13 @@ class DMChannel(abc.Messageable, abc.PrivateChannel, Hashable, PinsMixin):
         - :attr:`~Permissions.manage_messages`: You cannot delete others messages in a DM.
 
         Parameters
-        -----------
+        ----------
         obj: :class:`User`
             The user to check permissions for. This parameter is ignored
             but kept for compatibility with other ``permissions_for`` methods.
 
         Returns
-        --------
+        -------
         :class:`Permissions`
             The resolved permissions.
         """
@@ -2444,12 +2466,12 @@ class DMChannel(abc.Messageable, abc.PrivateChannel, Hashable, PinsMixin):
         .. versionadded:: 1.6
 
         Parameters
-        ------------
+        ----------
         message_id: :class:`int`
             The message ID to create a partial message for.
 
         Returns
-        ---------
+        -------
         :class:`PartialMessage`
             The partial message.
         """
@@ -2507,7 +2529,7 @@ class GroupChannel(abc.Messageable, abc.PrivateChannel, Hashable, PinsMixin):
         self._update_group(data)
 
     def _update_group(self, data: GroupChannelPayload) -> None:
-        self.owner_id: Optional[int] = utils._get_as_snowflake(data, "owner_id")
+        self.owner_id: Optional[int] = utils.get_as_snowflake(data, "owner_id")
         self._icon: Optional[str] = data.get("icon")
         self.name: Optional[str] = data.get("name")
         self.recipients: List[User] = [
@@ -2567,12 +2589,12 @@ class GroupChannel(abc.Messageable, abc.PrivateChannel, Hashable, PinsMixin):
         This also checks the kick_members permission if the user is the owner.
 
         Parameters
-        -----------
+        ----------
         obj: :class:`~abc.Snowflake`
             The user to check permissions for.
 
         Returns
-        --------
+        -------
         :class:`Permissions`
             The resolved permissions for the user.
         """
@@ -2596,7 +2618,7 @@ class GroupChannel(abc.Messageable, abc.PrivateChannel, Hashable, PinsMixin):
         If you are the only one in the group, this deletes it as well.
 
         Raises
-        -------
+        ------
         HTTPException
             Leaving the group failed.
         """
@@ -2629,7 +2651,7 @@ class PartialMessageable(abc.Messageable, Hashable):
             Returns the partial messageable's hash.
 
     Attributes
-    -----------
+    ----------
     id: :class:`int`
         The channel ID associated with this partial messageable.
     type: Optional[:class:`ChannelType`]
@@ -2652,12 +2674,12 @@ class PartialMessageable(abc.Messageable, Hashable):
         doing an unnecessary API call.
 
         Parameters
-        ------------
+        ----------
         message_id: :class:`int`
             The message ID to create a partial message for.
 
         Returns
-        ---------
+        -------
         :class:`PartialMessage`
             The partial message.
         """
