@@ -1,7 +1,8 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2015-present Rapptz
+Copyright (c) 2015-2021 Rapptz
+Copyright (c) 2022-present tag-epic
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -24,6 +25,8 @@ DEALINGS IN THE SOFTWARE.
 
 from typing import List, Literal, Optional, TypedDict
 
+from typing_extensions import NotRequired
+
 from .activity import PartialPresenceUpdate
 from .channel import GuildChannel
 from .emoji import Emoji
@@ -42,32 +45,9 @@ class Ban(TypedDict):
     user: User
 
 
-class _UnavailableGuildOptional(TypedDict, total=False):
-    unavailable: bool
-
-
-class UnavailableGuild(_UnavailableGuildOptional):
+class UnavailableGuild(TypedDict):
     id: Snowflake
-
-
-class _GuildOptional(TypedDict, total=False):
-    icon_hash: Optional[str]
-    owner: bool
-    permissions: str
-    widget_enabled: bool
-    widget_channel_id: Optional[Snowflake]
-    joined_at: Optional[str]
-    large: bool
-    member_count: int
-    voice_states: List[GuildVoiceState]
-    members: List[Member]
-    channels: List[GuildChannel]
-    presences: List[PartialPresenceUpdate]
-    threads: List[Thread]
-    max_presences: Optional[int]
-    max_members: int
-    premium_subscription_count: int
-    max_video_channel_users: int
+    unavailable: NotRequired[bool]
 
 
 DefaultMessageNotificationLevel = Literal[0, 1]
@@ -81,6 +61,7 @@ GuildFeature = Literal[
     "ANIMATED_ICON",
     "BANNER",
     "COMMUNITY",
+    "DEVELOPER_SUPPORT_SERVER",
     "DISCOVERABLE",
     "FEATURABLE",
     "INVITE_SPLASH",
@@ -121,7 +102,7 @@ class GuildPreview(_BaseGuildPreview, _GuildPreviewUnique):
     ...
 
 
-class Guild(_BaseGuildPreview, _GuildOptional):
+class Guild(_BaseGuildPreview):
     owner_id: Snowflake
     region: str
     afk_channel_id: Optional[Snowflake]
@@ -142,6 +123,23 @@ class Guild(_BaseGuildPreview, _GuildOptional):
     preferred_locale: str
     public_updates_channel_id: Optional[Snowflake]
     guild_scheduled_events: Optional[List[ScheduledEvent]]
+    icon_hash: NotRequired[Optional[str]]
+    owner: NotRequired[bool]
+    permissions: NotRequired[str]
+    widget_enabled: NotRequired[bool]
+    widget_channel_id: NotRequired[Optional[Snowflake]]
+    joined_at: NotRequired[Optional[str]]
+    large: NotRequired[bool]
+    member_count: NotRequired[int]
+    voice_states: NotRequired[List[GuildVoiceState]]
+    members: NotRequired[List[Member]]
+    channels: NotRequired[List[GuildChannel]]
+    presences: NotRequired[List[PartialPresenceUpdate]]
+    threads: NotRequired[List[Thread]]
+    max_presences: NotRequired[Optional[int]]
+    max_members: NotRequired[int]
+    premium_subscription_count: NotRequired[int]
+    max_video_channel_users: NotRequired[int]
 
 
 class InviteGuild(Guild, total=False):
@@ -163,9 +161,6 @@ class ChannelPositionUpdate(TypedDict):
     parent_id: Optional[Snowflake]
 
 
-class _RolePositionRequired(TypedDict):
+class RolePositionUpdate(TypedDict):
     id: Snowflake
-
-
-class RolePositionUpdate(_RolePositionRequired, total=False):
-    position: Optional[Snowflake]
+    position: NotRequired[Optional[Snowflake]]
